@@ -365,9 +365,14 @@ class RobotSChybou(object):
         return Sx,Sy
 
     def getOnlyRadius(self):#vrati polomer po ktorom sa dany robot toci
-        if(self.f1==self.f2):
-            raise AssertionError("Robot sa netoci, ale ide vpred")
-        radius=(self.s/2.)*(float(self.f1+self.f2)/float(self.f2-self.f1))#vzorec na vypocet polomeru otacania
+        radius = 0
+        if(self.f1 == 0 and self.f2 == 0):
+            radius = 0
+        else:
+            if(self.f1==self.f2):
+                raise AssertionError("Robot sa netoci, ale ide vpred")
+            else:
+                radius=(self.s/2.)*(float(self.f1+self.f2)/float(self.f2-self.f1))#vzorec na vypocet polomeru otacania
         return radius
 
     def dajSuradniceStreduAPolomer(self,x1,y1,x2,y2,alpha):
