@@ -9,7 +9,7 @@ import robot as rob
 
 #zoznamBodov = np.array([(0.0,5),(75,5),(-150.0,-80.0),(110.0,-80),(100.0,-50.0),(-150.0,150.0),(0.0,15.0),(200,-100)])
 #zoznamBodov = np.array([(0.0,0.0),(119.5,120.0),(-150.0,-80.0),(110.0,30.0),(-150.0,-80.0),(100.0,-50.0),(-150.0,150.0),(0.0,15.0),(45.0,16.0),(150.0,7.0)])
-zoznamBodov = fun.generate_points(N=15)
+zoznamBodov = fun.generate_points(N=10)
 fun.point_check(zoznamBodov)
 zoznamVzdialenosti = []#naplni sa vzdialenostmi medzi jednotlivymi bodmi
 zoznamUhlov = []#naplni sa hodnotami uhlov o ake ma byt robot natoceny v radianoch voci y-osi
@@ -242,7 +242,7 @@ def vykresliRobota(i):
 fig, ax = plt.subplots()
 #nastavenie ciar
 time_text = ax.text(0.05, 0.95, '', transform=ax.transAxes)
-odchylka_text = ax.text(0.75, 0.95, '', transform=ax.transAxes)
+odchylka_text = ax.text(0.55, 0.95, '', transform=ax.transAxes)
 time_template = 'uhol = %.1f stupnov'
 odchylka_template = 'odchylka = %.1f stupnov'
 
@@ -294,8 +294,8 @@ for label, x, y in zip(labels, data[:, 0], data[:, 1]):
         bbox = dict(boxstyle = 'round,pad=0.5', fc = 'yellow', alpha = 0.5),
         arrowprops = dict(arrowstyle = '->', connectionstyle = 'arc3,rad=0'))
 #maximalizacia okna
-mng = plt.get_current_fig_manager()
-mng.frame.Maximize(True)
+#mng = plt.get_current_fig_manager()
+#mng.frame.Maximize(True)
 plt.show()
 anim = animation.FuncAnimation(fig,vykresliRobota, frames=1000000,init_func=init, interval = 1, blit = True)
 show()
